require 'pstore'

class SparaDisk
  def initialize(name)
    @store = PStore.new(name)
  end

  def set(key, value)
    @store.transaction { @store[key] = value }
  end

  def get(key)
    @store.transaction(true) { @store.fetch(key, nil) }
  end

  def del(key)
    @store.transaction { @store.delete(key) }
  end

  def keys
    @store.transaction(true) { @store.roots }
  end

  def vals
    @store.transaction(true) do
      # @store.instance_variable_get(:@table).values
      @store.roots.inject([]) do |values, key|
        values.push(@store[key])
        values
      end
    end
  end

  def all
    @store.transaction(true) do
      # @store.instance_variable_get(:@table)
      @store.roots.inject({}) do |db, key|
        db[key] = @store[key]
        db
      end
    end
  end

  def clean!
    @store.transaction do
      @store.roots.each { |key| @store.delete(key) }
    end
  end
end
